@@ -32,6 +32,7 @@ test.decode("Cutset (Chain)", decode.cutset, Small, c(1), "chain")
 test.decode("JunctionTree", decode.junction, Small)
 test.decode("Sample", decode.sample, Small, sample.exact, 10000)
 test.decode("LBP", decode.lbp, Small)
+test.decode("RBP", decode.rbp, Small)
 test.decode("TRBP", decode.trbp, Small)
 test.decode("Greedy", decode.greedy, Small)
 test.decode("Greedy (Restart)", decode.greedy, Small, restart = 100)
@@ -51,6 +52,7 @@ test.decode("Cutset (Chain)", decode.cutset, Chain, c(1), "chain")
 test.decode("JunctionTree", decode.junction, Chain)
 test.decode("Sample", decode.sample, Chain, sample.chain, 10000)
 test.decode("LBP", decode.lbp, Chain)
+test.decode("RBP", decode.rbp, Chain)
 test.decode("TRBP", decode.trbp, Chain)
 test.decode("Greedy", decode.greedy, Chain)
 test.decode("Greedy (Restart)", decode.greedy, Chain, restart = 100)
@@ -68,6 +70,7 @@ test.decode("Cutset", decode.cutset, Tree, c(3))
 test.decode("JunctionTree", decode.junction, Tree)
 test.decode("Sample", decode.sample, Tree, sample.tree, 10000)
 test.decode("LBP", decode.lbp, Tree)
+test.decode("RBP", decode.rbp, Tree)
 test.decode("TRBP", decode.trbp, Tree)
 test.decode("Greedy", decode.greedy, Tree)
 test.decode("Greedy (Restart)", decode.greedy, Tree, restart = 100)
@@ -85,6 +88,7 @@ test.decode("Cutset (Chain)", decode.cutset, Loop, c(1), "chain")
 test.decode("JunctionTree", decode.junction, Loop)
 test.decode("Sample", decode.sample, Loop, sample.exact, 10000)
 test.decode("LBP", decode.lbp, Loop)
+test.decode("RBP", decode.rbp, Loop)
 test.decode("TRBP", decode.trbp, Loop)
 test.decode("Greedy", decode.greedy, Loop)
 test.decode("Greedy (Restart)", decode.greedy, Loop, restart = 100)
@@ -101,6 +105,7 @@ test.decode("Cutset", decode.cutset, Clique, c(1,3))
 test.decode("JunctionTree", decode.junction, Clique)
 test.decode("Sample", decode.sample, Clique, sample.exact, 10000)
 test.decode("LBP", decode.lbp, Clique)
+test.decode("RBP", decode.rbp, Clique)
 test.decode("TRBP", decode.trbp, Clique)
 test.decode("Greedy", decode.greedy, Clique, c(1,1,1,2))
 test.decode("Greedy (Restart)", decode.greedy, Clique, restart = 100)
